@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class SearchableSnapshotsClient(NamespacedClient):
@@ -24,15 +24,14 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Clear the cache of searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
             This API is **experimental** so may include breaking changes
             or be removed in a future version
 
-        :arg index: A comma-separated list of index name to limit the
-            operation
+        :arg index: A comma-separated list of index names
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -49,12 +48,12 @@ class SearchableSnapshotsClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params("master_timeout", "wait_for_completion")
+    @query_params("master_timeout", "storage", "wait_for_completion")
     def mount(self, repository, snapshot, body, params=None, headers=None):
         """
         Mount a snapshot as a searchable index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/searchable-snapshots-api-mount-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-api-mount-snapshot.html>`_
 
         .. warning::
 
@@ -68,6 +67,8 @@ class SearchableSnapshotsClient(NamespacedClient):
             as searchable
         :arg master_timeout: Explicit operation timeout for connection
             to master node
+        :arg storage: Selects the kind of local storage used to
+            accelerate searches. Experimental, and defaults to `full_copy`
         :arg wait_for_completion: Should this request wait until the
             operation has completed before returning
         """
@@ -88,7 +89,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         DEPRECATED: This API is replaced by the Repositories Metering API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -107,12 +108,12 @@ class SearchableSnapshotsClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params()
+    @query_params("level")
     def stats(self, index=None, params=None, headers=None):
         """
-        Retrieve various statistics about searchable snapshots.
+        Retrieve shard-level statistics about searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -120,6 +121,8 @@ class SearchableSnapshotsClient(NamespacedClient):
             or be removed in a future version
 
         :arg index: A comma-separated list of index names
+        :arg level: Return stats aggregated at cluster, index or shard
+            level  Valid choices: cluster, indices, shards  Default: indices
         """
         return self.transport.perform_request(
             "GET",
@@ -127,3 +130,27 @@ class SearchableSnapshotsClient(NamespacedClient):
             params=params,
             headers=headers,
         )
+
+    @query_params()
+    def cache_stats(self, node_id=None, params=None, headers=None):
+        """
+        Retrieve node-level cache statistics about searchable snapshots.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
+
+        .. warning::
+
+            This API is **experimental** so may include breaking changes
+            or be removed in a future version
+
+        :arg node_id: A comma-separated list of node IDs or names to
+            limit the returned information; use `_local` to return information from
+            the node you're connecting to, leave empty to get information from all
+            nodes
+        """
+        return self.transport.perform_request(
+            "GET",
+            _make_path("_searchable_snapshots", node_id, "cache", "stats"),
+            params=params,
+            headers=headers,
+        )
