@@ -25,7 +25,7 @@ class SslClient(NamespacedClient):
         Retrieves information about the X.509 certificates used to encrypt
         communications in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/security-api-ssl.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/security-api-ssl.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_ssl/certificates", params=params, headers=headers
