@@ -20,7 +20,7 @@ import time
 from operator import methodcaller
 
 from ..compat import Mapping, Queue, map, string_types
-from ..exceptions import TransportError
+from ..exceptions import NotFoundError, TransportError
 from .errors import BulkIndexError, ScanError
 
 logger = logging.getLogger("elasticsearch.helpers")
@@ -161,7 +161,7 @@ def _chunk_actions(actions, chunk_size, max_chunk_bytes, serializer):
         yield ret
 
 
-def _process_bulk_chunk_success(resp, bulk_data, raise_on_error=True):
+def _process_bulk_chunk_success(resp, bulk_data, ignore_status, raise_on_error=True):
     # if raise on error is set, we need to collect errors per chunk before raising them
     errors = []
 
@@ -169,8 +169,10 @@ def _process_bulk_chunk_success(resp, bulk_data, raise_on_error=True):
     for data, (op_type, item) in zip(
         bulk_data, map(methodcaller("popitem"), resp["items"])
     ):
-        ok = 200 <= item.get("status", 500) < 300
-        if not ok and raise_on_error:
+        status_code = item.get("status", 500)
+
+        ok = 200 <= status_code < 300
+        if not ok and raise_on_error and status_code not in ignore_status:
             # include original document source
             if len(data) > 1:
                 item["data"] = data[1]
@@ -186,10 +188,10 @@ def _process_bulk_chunk_success(resp, bulk_data, raise_on_error=True):
 
 
 def _process_bulk_chunk_error(
-    error, bulk_data, raise_on_exception=True, raise_on_error=True
+    error, bulk_data, ignore_status, raise_on_exception=True, raise_on_error=True
 ):
     # default behavior - just propagate exception
-    if raise_on_exception:
+    if raise_on_exception and error.status_code not in ignore_status:
         raise error
 
     # if we are not propagating, mark all actions in current chunk as failed
@@ -206,7 +208,7 @@ def _process_bulk_chunk_error(
         exc_errors.append({op_type: info})
 
     # emulate standard behavior for failed actions
-    if raise_on_error:
+    if raise_on_error and error.status_code not in ignore_status:
         raise BulkIndexError(
             "%i document(s) failed to index." % len(exc_errors), exc_errors
         )
@@ -221,6 +223,7 @@ def _process_bulk_chunk(
     bulk_data,
     raise_on_exception=True,
     raise_on_error=True,
+    ignore_status=(),
     *args,
     **kwargs
 ):
@@ -229,19 +232,26 @@ def _process_bulk_chunk(
     """
     kwargs = _add_helper_meta_to_kwargs(kwargs, "bp")
 
+    if not isinstance(ignore_status, (list, tuple)):
+        ignore_status = (ignore_status,)
+
     try:
         # send the actual request
-        resp = client.bulk("\n".join(bulk_actions) + "\n", *args, **kwargs)
+        resp = client.bulk(*args, body="\n".join(bulk_actions) + "\n", **kwargs)
     except TransportError as e:
         gen = _process_bulk_chunk_error(
             error=e,
             bulk_data=bulk_data,
+            ignore_status=ignore_status,
             raise_on_exception=raise_on_exception,
             raise_on_error=raise_on_error,
         )
     else:
         gen = _process_bulk_chunk_success(
-            resp=resp, bulk_data=bulk_data, raise_on_error=raise_on_error
+            resp=resp,
+            bulk_data=bulk_data,
+            ignore_status=ignore_status,
+            raise_on_error=raise_on_error,
         )
     for item in gen:
         yield item
@@ -266,6 +276,7 @@ def streaming_bulk(
     initial_backoff=2,
     max_backoff=600,
     yield_ok=True,
+    ignore_status=(),
     *args,
     **kwargs
 ):
@@ -301,6 +312,7 @@ def streaming_bulk(
         2**retry_number``
     :arg max_backoff: maximum number of seconds a retry will wait
     :arg yield_ok: if set to False will skip successful documents in the output
+    :arg ignore_status: list of HTTP status code that you want to ignore
     """
     actions = map(expand_action_callback, actions)
 
@@ -322,6 +334,7 @@ def streaming_bulk(
                         bulk_data,
                         raise_on_exception,
                         raise_on_error,
+                        ignore_status,
                         *args,
                         **kwargs
                     ),
@@ -358,7 +371,7 @@ def streaming_bulk(
                 bulk_actions, bulk_data = to_retry, to_retry_data
 
 
-def bulk(client, actions, stats_only=False, *args, **kwargs):
+def bulk(client, actions, stats_only=False, ignore_status=(), *args, **kwargs):
     """
     Helper for the :meth:`~elasticsearch.Elasticsearch.bulk` api that provides
     a more human friendly interface - it consumes an iterator of actions and
@@ -380,6 +393,7 @@ def bulk(client, actions, stats_only=False, *args, **kwargs):
     :arg actions: iterator containing the actions
     :arg stats_only: if `True` only report number of successful/failed
         operations instead of just number of successful and a list of error responses
+    :arg ignore_status: list of HTTP status code that you want to ignore
 
     Any additional keyword arguments will be passed to
     :func:`~elasticsearch.helpers.streaming_bulk` which is used to execute
@@ -393,7 +407,9 @@ def bulk(client, actions, stats_only=False, *args, **kwargs):
 
     # make streaming_bulk yield successful results so we can count them
     kwargs["yield_ok"] = True
-    for ok, item in streaming_bulk(client, actions, *args, **kwargs):
+    for ok, item in streaming_bulk(
+        client, actions, ignore_status=ignore_status, *args, **kwargs
+    ):
         # go through request-response pairs and detect failures
         if not ok:
             if not stats_only:
@@ -413,6 +429,7 @@ def parallel_bulk(
     max_chunk_bytes=100 * 1024 * 1024,
     queue_size=4,
     expand_action_callback=expand_action,
+    ignore_status=(),
     *args,
     **kwargs
 ):
@@ -433,6 +450,7 @@ def parallel_bulk(
         (`None` if data line should be omitted).
     :arg queue_size: size of the task queue between the main thread (producing
         chunks to send) and the processing threads.
+    :arg ignore_status: list of HTTP status code that you want to ignore
     """
     # Avoid importing multiprocessing unless parallel_bulk is used
     # to avoid exceptions on restricted environments like App Engine
@@ -454,7 +472,12 @@ def parallel_bulk(
         for result in pool.imap(
             lambda bulk_chunk: list(
                 _process_bulk_chunk(
-                    client, bulk_chunk[1], bulk_chunk[0], *args, **kwargs
+                    client,
+                    bulk_chunk[1],
+                    bulk_chunk[0],
+                    ignore_status=ignore_status,
+                    *args,
+                    **kwargs
                 )
             ),
             _chunk_actions(
@@ -527,9 +550,26 @@ def scan(
         query = query.copy() if query else {}
         query["sort"] = "_doc"
 
+    # Grab options that should be propagated to every
+    # API call within this helper instead of just 'search()'
+    transport_kwargs = {}
+    for key in ("headers", "api_key", "http_auth"):
+        if key in kwargs:
+            transport_kwargs[key] = kwargs[key]
+
+    # If the user is using 'scroll_kwargs' we want
+    # to propagate there too, but to not break backwards
+    # compatibility we'll not override anything already given.
+    if scroll_kwargs is not None and transport_kwargs:
+        for key, val in transport_kwargs.items():
+            scroll_kwargs.setdefault(key, val)
+
     # initial search
+    search_kwargs = kwargs.copy()
+    if query:
+        search_kwargs.update(query)
     resp = client.search(
-        body=query, scroll=scroll, size=size, request_timeout=request_timeout, **kwargs
+        scroll=scroll, size=size, request_timeout=request_timeout, **search_kwargs
     )
     scroll_id = resp.get("_scroll_id")
 
@@ -562,17 +602,16 @@ def scan(
                             shards_total,
                         ),
                     )
-            resp = client.scroll(
-                body={"scroll_id": scroll_id, "scroll": scroll}, **scroll_kwargs
-            )
+            resp = client.scroll(scroll_id=scroll_id, scroll=scroll, **scroll_kwargs)
             scroll_id = resp.get("_scroll_id")
 
     finally:
         if scroll_id and clear_scroll:
             client.clear_scroll(
-                body={"scroll_id": [scroll_id]},
+                scroll_id=scroll_id,
                 ignore=(404,),
                 params={"__elastic_client_meta": (("h", "s"),)},
+                **transport_kwargs
             )
 
 
@@ -584,6 +623,7 @@ def reindex(
     target_client=None,
     chunk_size=500,
     scroll="5m",
+    op_type=None,
     scan_kwargs={},
     bulk_kwargs={},
 ):
@@ -613,6 +653,9 @@ def reindex(
     :arg chunk_size: number of docs in one chunk sent to es (default: 500)
     :arg scroll: Specify how long a consistent view of the index should be
         maintained for scrolled search
+    :arg op_type: Explicit operation type. Defaults to '_index'. Data streams must
+        be set to 'create'. If not specified, will auto-detect if target_index is a
+        data stream.
     :arg scan_kwargs: additional kwargs to be passed to
         :func:`~elasticsearch.helpers.scan`
     :arg bulk_kwargs: additional kwargs to be passed to
@@ -621,18 +664,41 @@ def reindex(
     target_client = client if target_client is None else target_client
     docs = scan(client, query=query, index=source_index, scroll=scroll, **scan_kwargs)
 
-    def _change_doc_index(hits, index):
+    def _change_doc_index(hits, index, op_type):
         for h in hits:
             h["_index"] = index
+            if op_type is not None:
+                h["_op_type"] = op_type
             if "fields" in h:
                 h.update(h.pop("fields"))
             yield h
 
     kwargs = {"stats_only": True}
     kwargs.update(bulk_kwargs)
+
+    is_data_stream = False
+    try:
+        # Verify if the target_index is data stream or index
+        data_streams = target_client.indices.get_data_stream(
+            target_index, expand_wildcards="all"
+        )
+        is_data_stream = any(
+            data_stream["name"] == target_index
+            for data_stream in data_streams["data_streams"]
+        )
+    except (TransportError, KeyError, NotFoundError):
+        # If its not data stream, might be index
+        pass
+
+    if is_data_stream:
+        if op_type not in (None, "create"):
+            raise ValueError("Data streams must have 'op_type' set to 'create'")
+        else:
+            op_type = "create"
+
     return bulk(
         target_client,
-        _change_doc_index(docs, target_index),
+        _change_doc_index(docs, target_index, op_type),
         chunk_size=chunk_size,
         **kwargs
     )
